@@ -128,7 +128,10 @@ class AbstractDocUnit(object):
                     navdir = os.path.join(chapdir, sects[index])
                     nav_filepath = os.path.join(navdir, filepath)
                     navfile = open(nav_filepath, 'w')
-                    navfile.write(self.pretty_json(self.sections[index])+'\n')
+                    if index == 7:
+                        navfile.write(self.sections[index]+'\n')
+                    else:
+                        navfile.write(self.pretty_json(self.sections[index])+'\n')
                     navfile.close()
                 else:
                     chapter_file.write('#### '+sects[index]+'/\n') # trailng slash indicates an empty code section
@@ -182,7 +185,7 @@ class AbstractDocUnit(object):
         if len(self.sections[RUNTIME]) > 2:
             doc_string += '\n#### runtime'
             doc_string += '\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  python\n'
-            doc_string += self.pretty_json(self.sections[RUNTIME])
+            doc_string += self.sections[RUNTIME]
             doc_string += '\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n'
         else:
             doc_string += '\n#### runtime/\n'
@@ -193,7 +196,7 @@ class AbstractDocUnit(object):
         if len(self.sections[STATUS]) > 0:
             doc_string += '\n#### status'
             doc_string += '\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  json\n'
-            doc_string += self.sections[STATUS]
+            doc_string += self.pretty_json(self.sections[STATUS])
             doc_string += '\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n'
         else:
             doc_string += '\n#### status/\n'
@@ -324,12 +327,13 @@ class ChapterDocUnit(AbstractDocUnit):
             route.print_all_to_file(outfile, response)
 
     def print_nav_to_file(self, parent_dir, response=True):
-        chapter_filepath = os.path.join(parent_dir, 'chapter/'+self.get_keypath(section=CHAPTER)+'.ddd')
+        chapter_filepath = os.path.join(parent_dir, 'chapter/'+self.get_keypath(section=CHAPTER)+'.nav.dd')
         nav_out = open(chapter_filepath, 'w')
         nav_out.write('# '+self.title+'\n')
         self.write_nav_files(os.path.join(parent_dir, 'chapter/'), nav_out)
         for route in self.route_list:
-            route.print_nav_to_file(os.path.join(parent_dir, 'chapter/'), nav_out)
+            nav_out.write('## '+route.title+'\n')
+            route.write_nav_files(os.path.join(parent_dir, 'chapter/'), nav_out)
         nav_out.close()
 
     def accumulate_route_status(self):
@@ -372,10 +376,6 @@ class RouteDocUnit(AbstractDocUnit):
         outfile.write('\n## '+self.title+'\n')
         outfile.write(self.as_string(response))
 
-    def print_nav_to_file(self, chapter_dir, nav_outfile):
-        nav_outfile.write('## '+self.title+'\n')
-        self.write_nav_files(chapter_dir, nav_outfile)
-
     def get_json_doc_struct(self):
         return {
             self.title: {
@@ -439,20 +439,20 @@ class DrivenDownDoc(object):
 
 
     def print_nav_to_file(self, parent_dir, response=True):
-        nav_path = os.path.join(parent_dir, title2filename(self.title)+'.nav.ddd')
+        nav_path = os.path.join(parent_dir, title2filename(self.title)+'.nav.dd')
         navfile = open(nav_path, 'w')
         if self.title: navfile.write('% '+self.title+'\n')
         if self.author: navfile.write('% '+self.author+'\n')
         if self.date: navfile.write('% '+datetime.datetime.now().strftime('%A, %B %d, %I:%M:%S %p %z')+'\n')
         if self.introduction:
-            navfile.write('%# chapter/'+self.introduction.key_filepath+'.ddd\n')
+            navfile.write('%# chapter/'+self.introduction.key_filepath+'.nav.dd\n')
             self.introduction.print_nav_to_file(parent_dir, response=response)
         for chapter in self.chapter_list:
             chapter.print_nav_to_file(parent_dir, response=response)
-            navfile.write('%# chapter/'+chapter.key_filepath+'.ddd\n')
+            navfile.write('%# chapter/'+chapter.key_filepath+'.nav.dd\n')
         if self.conclusion:
             self.conclusion.print_nav_to_file(parent_dir, response=response)
-            navfile.write('%# chapter/'+self.conclusion.key_filepath+'.ddd\n')
+            navfile.write('%# chapter/'+self.conclusion.key_filepath+'.nav.dd\n')
 
 
 
@@ -566,7 +566,7 @@ def initialize(doc_filepath, debug_output=None):
         print 'continuing with no debug_output'
 
     if print_feed:
-        print '@@@@@@@@@@@@@@@@@@@@@@@@@ DDD FEED @@@@@@@@@@@@@@@@@@@@@@@@@'
+        print '@@@@@@@@@@@@@@@@@@@@@@@@@ dd FEED @@@@@@@@@@@@@@@@@@@@@@@@@'
     global driven_down_doc
     driven_down_doc = DrivenDownDoc()
     root_dir, basename = os.path.split(doc_filepath)
@@ -578,11 +578,12 @@ def initialize(doc_filepath, debug_output=None):
 link_to_file_pattern = '(^%# (\w+.*)|^#### ((config|predict|response|runtime|status)/\w+.*))'
 regex = re.compile(link_to_file_pattern)
 def feed_file(driven_down_doc, filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl=0):
+    full_filepath = os.path.join(root_dir, filepath)
     if file_feed:
-        print 'docdriven: '+filepath
-    filename = os.path.basename(filepath)
+        print 'docdriven: '+full_filepath
+    filename = os.path.basename(full_filepath)
     from_filekey = filename[:filename.rfind('.')] # last index of .
-    feeder_file = open(filepath, 'r')
+    feeder_file = open(full_filepath, 'r')
     for line in feeder_file:
         match = regex.search(line)
         if match:
@@ -592,8 +593,8 @@ def feed_file(driven_down_doc, filepath, root_dir, line_feed, file_feed, print_f
                 print ' '*(4*rcrsn_lvl)+'+---+ '+line,
             if not path.startswith(('config/', 'predict/', 'response/', 'runtime/', 'status/', 'chapter/')):
                 raise Exception('cannot import from unrecognized location: '+path)
-            if not path.endswith(('.json', '.py', '.ddd')):
-                raise 'cannot import unrecognized filetype: '+path
+            if not path.endswith(('.json', '.py', '.dd')):
+                raise Exception('cannot import unrecognized filetype: '+path)
             if not path.startswith('chapter/'):
                 path = 'chapter/'+path
             include_filepath = os.path.join(root_dir, path)
@@ -615,21 +616,21 @@ def feed_line(driven_down_doc, line, from_filekey, line_feed, print_feed, rcrsn_
     if print_feed:
         print ' '*(4*rcrsn_lvl)+'| '+line
     if line_feed:
-        print 'docdriven:   '+line
+        print 'docdriven:    '+line.rstrip()
     driven_down_doc.feed_line(line, from_filekey)
 
-def print_to_files(parent_dirpath, ddd_all_response=True):
+def print_to_files(parent_dirpath, dd_all_response=True):
     print 'parent_dirpath='+str(parent_dirpath)
     global driven_down_doc
     filepath = os.path.join(parent_dirpath, title2filename(driven_down_doc.title))
     report_filepath = os.path.join(parent_dirpath, 'reports/')
     report_filepath = os.path.join(report_filepath, title2filename(driven_down_doc.title))
 
-    ddd_all_file = open(filepath+'.all.ddd', 'w')
-    driven_down_doc.print_all_to_file(ddd_all_file, ddd_all_response)
-    ddd_all_file.close()
+    dd_all_file = open(filepath+'.all.dd', 'w')
+    driven_down_doc.print_all_to_file(dd_all_file, dd_all_response)
+    dd_all_file.close()
 
-    driven_down_doc.print_nav_to_file(parent_dirpath, response=ddd_all_response)
+    driven_down_doc.print_nav_to_file(parent_dirpath, response=dd_all_response)
 
     status_filepath = report_filepath+'.status'
     try:
@@ -657,7 +658,7 @@ def get_json_doc_structure():
     return driven_down_doc.get_json_doc_structure()
 
 if __name__ == '__main__':
-    routes_filepath = '/Users/Jon/dev/iit/nebula1/cwautopro/routes.ddd'
+    routes_filepath = '/Users/Jon/dev/iit/nebula1/cwautopro/routes.dd'
     initialize(routes_filepath)
     print_to_file(routes_filepath)
 
